@@ -6,7 +6,7 @@ use Carp qw( croak );
 use base qw( FFI::Platypus::TypeParser );
 
 # ABSTRACT: FFI Type Parser Version One
-our $VERSION = '0.97_04'; # TRIAL VERSION
+our $VERSION = '0.97_05'; # TRIAL VERSION
 
 
 our @CARP_NOT = qw( FFI::Platypus FFI::Platypus::TypeParser );
@@ -119,7 +119,7 @@ sub parse
 
   if(defined (my $class = $5))  # class record
   {
-    my $size_method = $class->can('ffi_record_size') || $class->can('_ffi_record_size') || croak "$class has no ffi_record_size or _ffi_record_size_ method";
+    my $size_method = $class->can('ffi_record_size') || $class->can('_ffi_record_size') || croak "$class has no ffi_record_size or _ffi_record_size method";
     if(my $pointer = $6)
     {
       return $self->types->{$name} = $self->create_type_record(
@@ -285,7 +285,7 @@ FFI::Platypus::TypeParser::Version1 - FFI Type Parser Version One
 
 =head1 VERSION
 
-version 0.97_04
+version 0.97_05
 
 =head1 SYNOPSIS
 
